@@ -6,4 +6,4 @@ use HTTP::Response;
 my $uri = shift(@ARGV) or die "Usage: $0 URI\n";
 
 my $furl = Furl->new(headers => ['Accept-Encoding' => 'gzip']);
-print HTTP::Response->new( $furl->get($uri) )->as_string;
+print $furl->get($uri)->as_http_response->as_string;
